# pyhc-core

[![PyPI version](https://img.shields.io/pypi/v/pyhc-core.svg?cacheBuster=1)](https://pypi.org/project/pyhc-core/)

`pyhc-core` is a package that simplifies the installation of the core PyHC packages.

## Installation

You can install `pyhc-core` using pip:

```sh
pip install pyhc-core
```

To ensure the latest versions of the core packages are installed, use:
```sh
pip install --upgrade pyhc-core
```

## Core Packages

The following packages are included:
- hapiclient
- ~~kamodo~~ (temporarily excluded until it supports Python>=3.12)
- plasmapy
- pysat
- pyspedas
- spacepy
- sunpy

## Pip List Table
This table shows the output of running `pip list` after installing `pyhc-core` in a fresh environment (updated nightly):

| Package | Version |
|---------|---------|
| aioboto3 | 15.5.0 |
| aiobotocore | 2.25.1 |
| aiofiles | 25.1.0 |
| aioftp | 0.27.2 |
| aiohappyeyeballs | 2.6.1 |
| aiohttp | 3.13.3 |
| aioitertools | 0.13.0 |
| aiosignal | 1.4.0 |
| asdf | 5.1.0 |
| asdf-astropy | 0.10.0 |
| asdf_coordinates_schemas | 0.5.1 |
| asdf_standard | 1.5.0 |
| asdf_transform_schemas | 0.6.0 |
| asteval | 1.0.8 |
| astropy | 7.2.0 |
| astropy_healpix | 1.1.3 |
| astropy-iers-data | 0.2026.3.2.0.47.4 |
| attrs | 25.4.0 |
| beautifulsoup4 | 4.14.3 |
| boto3 | 1.40.61 |
| botocore | 1.40.61 |
| cdasws | 1.8.15 |
| cdflib | 1.3.8 |
| certifi | 2026.2.25 |
| cftime | 1.6.5 |
| charset-normalizer | 3.4.4 |
| click | 8.3.1 |
| cloudpickle | 3.1.2 |
| contourpy | 1.3.3 |
| cycler | 0.12.1 |
| dask | 2026.1.2 |
| dask-image | 2025.11.0 |
| dill | 0.4.1 |
| donfig | 0.8.1.post1 |
| drms | 0.9.0 |
| fonttools | 4.61.1 |
| frozenlist | 1.8.0 |
| fsspec | 2026.2.0 |
| geopack | 1.0.12 |
| Glymur | 0.14.7 |
| google-crc32c | 1.8.0 |
| h5netcdf | 1.8.1 |
| h5py | 3.15.1 |
| hapiclient | 0.2.6 |
| idna | 3.11 |
| ImageIO | 2.37.2 |
| iniconfig | 2.3.0 |
| isodate | 0.7.2 |
| jmespath | 1.1.0 |
| joblib | 1.5.3 |
| kiwisolver | 1.4.9 |
| lazy_loader | 0.4 |
| lmfit | 1.3.4 |
| locket | 1.0.0 |
| lxml | 6.0.2 |
| matplotlib | 3.10.8 |
| mpl_animators | 1.2.4 |
| mpmath | 1.4.0 |
| multidict | 6.7.1 |
| netCDF4 | 1.7.4 |
| networkx | 3.6.1 |
| numcodecs | 0.16.5 |
| numpy | 2.4.2 |
| opencv-python | 4.13.0.92 |
| packaging | 26.0 |
| pandas | 3.0.1 |
| parfive | 2.3.1 |
| partd | 1.4.2 |
| pillow | 12.1.1 |
| PIMS | 0.7 |
| pip | 26.0.1 |
| plasmapy | 2026.2.0 |
| platformdirs | 4.9.2 |
| pluggy | 1.6.0 |
| portalocker | 3.2.0 |
| propcache | 0.4.1 |
| pyarrow | 23.0.1 |
| PyAVM | 0.9.8 |
| pyerfa | 2.0.1.5 |
| Pygments | 2.19.2 |
| pyhc-core | 0.0.7 |
| pyparsing | 3.3.2 |
| pysat | 3.2.2 |
| pyspedas | 2.1.0 |
| pytest | 9.0.2 |
| python-dateutil | 2.9.0.post0 |
| pytz | 2026.1.post1 |
| PyWavelets | 1.9.0 |
| PyYAML | 6.0.3 |
| reproject | 0.19.0 |
| requests | 2.32.5 |
| requests-file | 3.0.1 |
| requests-toolbelt | 1.0.0 |
| s3fs | 2026.2.0 |
| s3transfer | 0.14.0 |
| scikit-image | 0.26.0 |
| scipy | 1.17.1 |
| semantic-version | 2.10.0 |
| setuptools | 81.0.0 |
| six | 1.17.0 |
| slicerator | 1.1.0 |
| soupsieve | 2.8.3 |
| spacepy | 0.7.0 |
| spiceypy | 8.0.2 |
| sunpy | 7.1.0 |
| tifffile | 2026.3.3 |
| toolz | 1.1.0 |
| tqdm | 4.67.3 |
| typing_extensions | 4.15.0 |
| uncertainties | 3.2.3 |
| urllib3 | 2.6.3 |
| wrapt | 1.17.3 |
| xarray | 2026.2.0 |
| yarl | 1.23.0 |
| zarr | 3.1.5 |
| zeep | 4.3.2 |
